@@ -4,9 +4,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.008000'; # VERSION
+our $VERSION = '0.009000'; # VERSION
 
 use Moose;
+with 'MooseY::RemoteHelper::Role::Client';
 
 use Moose::Util::TypeConstraints;
 
@@ -25,9 +26,54 @@ use XML::Compile::WSDL11;
 use XML::Compile::SOAP11;
 use XML::Compile::Transport::SOAPHTTP;
 
+our @CARP_NOT = ( __PACKAGE__, qw( Class::MOP::Method::Wrapped ) );
+
+around BUILDARGS => sub {
+    my $orig  = shift;
+    my $class = shift;
+
+	my $args = $class->$orig( @_ );
+
+	if ( exists $args->{username} ) {
+		warnings::warnif('deprecated',
+			'`username` is deprecated, use `user` instead'
+		);
+
+		$args->{user} = delete $args->{username};
+	}
+
+	if ( exists $args->{password} ) {
+		warnings::warnif('deprecated',
+			'`password` is deprecated, use `pass` instead'
+		);
+
+		$args->{pass} = delete $args->{password};
+	}
+
+	if ( exists $args->{production} ) {
+		warnings::warnif('deprecated',
+			'`production` is deprecated, use `test` instead'
+		);
+
+		$args->{test} = delete( $args->{production} ) ? 0 : 1;
+	}
+
+	return $args;
+};
+
 sub run_transaction {
 	my ( $self, $request ) = @_;
 
+	warnings::warnif('deprecated',
+		'run_transaction is deprecated, use submit instead'
+	);
+
+	return $self->submit( $request );
+}
+
+sub submit {
+	my ( $self, $request ) = @_;
+
 	confess 'request undefined'         unless defined $request;
 	confess 'request not an object'     unless blessed $request;
 	confess 'request can not serialize' unless $request->can('serialize');
@@ -44,7 +90,7 @@ sub run_transaction {
 	}
 
 	my %request = (
-		merchantID            => $self->_username,
+		merchantID            => $self->user,
 		clientEnvironment     => $self->env,
 		clientLibrary         => $self->name,
 		clientLibraryVersion  => $self->version,
@@ -53,7 +99,7 @@ sub run_transaction {
 
 	if ( $self->debug >= 1 ) {
 		load 'Carp';
-		load $self->_dumper_package, 'Dumper';
+		load 'Data::Printer', alias => 'Dumper';
 
 		Carp::carp( 'REQUEST HASH: ' . Dumper( \%request ) );
 	}
@@ -72,9 +118,6 @@ sub run_transaction {
 	}
 
 	if ( $self->debug >= 1 ) {
-		load 'Carp';
-		load $self->_dumper_package, 'Dumper';
-
 		Carp::carp( 'RESPONSE HASH: ' . Dumper( $answer->{result} ) );
 	}
 
@@ -91,8 +134,8 @@ sub _build_soap_client {
 	$wsdl->importDefinitions( $self->cybs_xsd->stringify );
 
 	$wss->basicAuth(
-		username => $self->_username,
-		password => $self->_password,
+		username => $self->user,
+		password => $self->pass,
 	);
 
 	my $call = $wsdl->compileClient('runTransaction');
@@ -103,7 +146,7 @@ sub _build_soap_client {
 sub _build_cybs_wsdl {
 	my $self = shift;
 
-	my $dir = $self->_production ? 'production' : 'test';
+	my $dir = $self->test ? 'test' : 'production';
 
 	load 'File::ShareDir::ProjectDistDir', 'dist_file';
 	return load_class('Path::Class::File')->new(
@@ -121,7 +164,7 @@ sub _build_cybs_wsdl {
 sub _build_cybs_xsd {
 	my $self = shift;
 
-	my $dir = $self->_production ? 'production' : 'test';
+	my $dir = $self->test ? 'test' : 'production';
 
 	load 'File::ShareDir::ProjectDistDir', 'dist_file';
 	return load_class('Path::Class::File')->new(
@@ -197,44 +240,6 @@ has _rules => (
 	traits     => ['Array'],
 );
 
-has debug => (
-	isa     => 'Int',
-	is      => 'ro',
-	lazy    => 1,
-	default => sub {
-		return $ENV{PERL_BUSINESS_CYBERSOURCE_DEBUG} // 0;
-	},
-);
-
-has _dumper_package => (
-	isa      => NonEmptySimpleStr,
-	is       => 'ro',
-	lazy     => 1,
-	init_arg => 'dumper_package',
-	default  => sub { return 'Data::Dumper'; },
-);
-
-has production => (
-	isa      => 'Bool',
-	reader   => '_production',
-	is       => 'ro',
-	required => 1,
-);
-
-has username => (
-	isa      => subtype( NonEmptySimpleStr, where { length $_ <= 30 }),
-	reader   => '_username',
-	is       => 'ro',
-	required => 1,
-);
-
-has password => (
-	isa      => NonEmptyStr,
-	reader   => '_password',
-	is       => 'ro',
-	required => 1,
-);
-
 has version => (
 	required => 0,
 	lazy     => 1,
@@ -310,7 +315,7 @@ Business::CyberSource::Client - User Agent Responsible for transmitting the Resp
 
 =head1 VERSION
 
-version 0.008000
+version 0.009000
 
 =head1 SYNOPSIS
 
@@ -319,9 +324,9 @@ version 0.008000
 	my $request = 'Some Business::CyberSource::Request Object';
 
 	my $client = Business::CyberSource::Request->new({
-		username   => 'Merchant ID',
-		password   => 'API KEY',
-		production => 0,
+		user => 'Merchant ID',
+		pass => 'API KEY',
+		test => 1,
 	});
 
 	my $response = $client->run_transaction( $request );
@@ -331,35 +336,42 @@ version 0.008000
 A service object that is meant to provide a way to run the requested
 transactions.
 
+=head1 WITH
+
+L<MooseY::RemoteHelper::Role::Client>
+
 =head1 METHODS
 
-=head2 run_transaction
+=head2 submit
 
-	my $response = $client->run_transaction( $request );
+	my $response = $client->submit( $request );
 
 Takes a L<Business::CyberSource::Request> subclass as a parameter and returns
 a L<Business::CyberSource::Response>
 
+=head2 run_transaction
+
+DEPRECATED, use L</submit>
+
 =head1 ATTRIBUTES
 
-=head2 username
+=head2 user
 
 CyberSource Merchant ID
 
-=head2 password
+=head2 pass
 
 CyberSource API KEY
 
-=head2 production
+=head2 test
 
-Boolean value when true your requests will go to the production server, when
-false they will go to the testing server
+Boolean value when false your requests will go to the live server, when
+true they will go to the testing server.
 
 =head2 debug
 
 Integer value that causes the HTTP request/response to be output to STDOUT
 when a transaction is run. defaults to value of the environment variable
-C<PERL_BUSINESS_CYBERSOURCE_DEBUG>.
 
 =over
 
@@ -386,11 +398,6 @@ L<Business::CyberSource::Rule::RequestIDisZero> are included. If you decide to
 add more rules remember to add C<qw( ExpiredCard RequestIDisZero )> to the
 new ArrayRef ( if you want them ).
 
-=head2 dumper_package
-
-Package name for dumping the request hash if doing a L<debug|/"debug">. Package
-must have a C<Dumper> function.
-
 =head2 name
 
 Client Name defaults to L<Business::CyberSource>
@@ -430,7 +437,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.
+This software is Copyright (c) 2013 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
