@@ -3,14 +3,11 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.008000'; # VERSION
+our $VERSION = '0.009000'; # VERSION
 
 use Moose;
-
-use MooseX::RemoteHelper;
+extends 'MooseY::RemoteHelper::MessagePart';
 use MooseX::SetOnce 0.200001;
-use MooseX::StrictConstructor;
-use MooseX::UndefTolerant;
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -27,7 +24,7 @@ Business::CyberSource::MessagePart - Things that all portions of a message have
 
 =head1 VERSION
 
-version 0.008000
+version 0.009000
 
 =head1 BUGS
 
@@ -44,7 +41,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.
+This software is Copyright (c) 2013 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
