@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.008000'; # VERSION
+our $VERSION = '0.009000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::MessagePart';
@@ -53,7 +53,7 @@ sub _build_expired {
 	return $self->_compare_date_against_expiration( DateTime->now );
 }
 
-sub _compare_date_against_expiration { ## no critic (Subroutines::RequireFinalReturn)
+sub _compare_date_against_expiration {
 	my ( $self, $date ) = @_;
 
 	my $exp = $self->expiration->clone;
@@ -64,17 +64,16 @@ sub _compare_date_against_expiration { ## no critic (Subroutines::RequireFinalRe
 	load_class('DateTime');
 	my $cmp = DateTime->compare( $date, $exp );
 
-	given ( $cmp ) {
-		when ( -1 ) { # current date is before than the expiration date
-			return 0;
-		}
-		when ( 0 ) { # expiration equal to current date
-			return 0;
-		}
-		when ( 1 ) { # current date is past the expiration date
-			return 1;
-		}
+	if    ( $cmp == -1 ) { # current date is before than the expiration date
+		return 0;
 	}
+	elsif ( $cmp ==  0 ) { # expiration equal to current date
+		return 0;
+	}
+	elsif ( $cmp ==  1 ) { # current date is past the expiration date
+		return 1;
+	}
+	return; # da F*? should never hit this
 }
 
 sub _build_card_type_code {
@@ -206,7 +205,7 @@ Business::CyberSource::RequestPart::Card - Credit Card Helper Class
 
 =head1 VERSION
 
-version 0.008000
+version 0.009000
 
 =head1 EXTENDS
 
@@ -333,7 +332,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.
+This software is Copyright (c) 2013 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
